==> camel-k-model-v1-5.3.0-sources.jar: annotations/io/fabric8/camelk/v1/FailureFluent.java <==
package io.fabric8.camelk.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface FailureFluent<A extends FailureFluent<A>> extends Fluent<A> {


    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(int[] arg1,int arg2,int arg3);
    public A withNewReason(char[] arg1);
    public A withNewReason(StringBuffer arg1);
    public A withNewReason(byte[] arg1,int arg2);
    public A withNewReason(byte[] arg1);
    public A withNewReason(char[] arg1,int arg2,int arg3);
    public A withNewReason(byte[] arg1,int arg2,int arg3);
    public A withNewReason(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewReason(String arg1);
    
/**
 * This method has been deprecated, please use method buildRecovery instead.
 * @return The buildable object.
 */
@Deprecated public FailureRecovery getRecovery();
    public FailureRecovery buildRecovery();
    public A withRecovery(FailureRecovery recovery);
    public Boolean hasRecovery();
    public A withNewRecovery(Integer attempt,Integer attemptMax,String attemptTime);
    public FailureFluent.RecoveryNested<A> withNewRecovery();
    public FailureFluent.RecoveryNested<A> withNewRecoveryLike(FailureRecovery item);
    public FailureFluent.RecoveryNested<A> editRecovery();
    public FailureFluent.RecoveryNested<A> editOrNewRecovery();
    public FailureFluent.RecoveryNested<A> editOrNewRecoveryLike(FailureRecovery item);
    public String getTime();
    public A withTime(String time);
    public Boolean hasTime();
    public A withNewTime(StringBuilder arg1);
    public A withNewTime(int[] arg1,int arg2,int arg3);
    public A withNewTime(char[] arg1);
    public A withNewTime(StringBuffer arg1);
    public A withNewTime(byte[] arg1,int arg2);
    public A withNewTime(byte[] arg1);
    public A withNewTime(char[] arg1,int arg2,int arg3);
    public A withNewTime(byte[] arg1,int arg2,int arg3);
    public A withNewTime(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewTime(String arg1);
    public interface RecoveryNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,FailureRecoveryFluent<FailureFluent.RecoveryNested<N>> {

            public N and();
            public N endRecovery();    }


}

==> camel-k-model-v1-5.3.1-sources.jar: annotations/io/fabric8/camelk/v1/FailureFluent.java <==
package io.fabric8.camelk.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface FailureFluent<A extends FailureFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(int[] arg1,int arg2,int arg3);
    public A withNewReason(char[] arg1);
    public A withNewReason(StringBuffer arg1);
    public A withNewReason(byte[] arg1,int arg2);
    public A withNewReason(byte[] arg1);
    public A withNewReason(char[] arg1,int arg2,int arg3);
    public A withNewReason(byte[] arg1,int arg2,int arg3);
    public A withNewReason(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewReason(String arg1);
    
/**
 * This method has been deprecated, please use method buildRecovery instead.
 * @return The buildable object.
 */
@Deprecated public FailureRecovery getRecovery();
    public FailureRecovery buildRecovery();
    public A withRecovery(FailureRecovery recovery);
    public Boolean hasRecovery();
    public A withNewRecovery(Integer attempt,Integer attemptMax,String attemptTime);
    public io.fabric8.camelk.v1.FailureFluent.RecoveryNested<A> withNewRecovery();
    public io.fabric8.camelk.v1.FailureFluent.RecoveryNested<A> withNewRecoveryLike(FailureRecovery item);
    public io.fabric8.camelk.v1.FailureFluent.RecoveryNested<A> editRecovery();
    public io.fabric8.camelk.v1.FailureFluent.RecoveryNested<A> editOrNewRecovery();
    public io.fabric8.camelk.v1.FailureFluent.RecoveryNested<A> editOrNewRecoveryLike(FailureRecovery item);
    public String getTime();
    public A withTime(String time);
    public Boolean hasTime();
    public A withNewTime(StringBuilder arg1);
    public A withNewTime(int[] arg1,int arg2,int arg3);
    public A withNewTime(char[] arg1);
    public A withNewTime(StringBuffer arg1);
    public A withNewTime(byte[] arg1,int arg2);
    public A withNewTime(byte[] arg1);
    public A withNewTime(char[] arg1,int arg2,int arg3);
    public A withNewTime(byte[] arg1,int arg2,int arg3);
    public A withNewTime(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewTime(String arg1);
    public interface RecoveryNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,FailureRecoveryFluent<io.fabric8.camelk.v1.FailureFluent.RecoveryNested<N>> {

            public N and();
            public N endRecovery();    }


}
